@@ -8,15 +8,17 @@ from typing import Dict, Any
 from sphinx.domains import ObjType
 from sphinx.application import Sphinx
 
-from sphinxcontrib.autodoc_pydantic.autodoc import (
+from sphinxcontrib.autodoc_pydantic.directives.autodocumenters import (
     PydanticValidatorDocumenter,
     PydanticModelDocumenter,
     PydanticConfigClassDocumenter,
     PydanticFieldDocumenter,
     PydanticSettingsDocumenter
 )
+from sphinxcontrib.autodoc_pydantic.directives.options.enums import \
+    OptionsJsonErrorStrategy, OptionsFieldDocPolicy, OptionsSummaryListOrder
 
-from sphinxcontrib.autodoc_pydantic.directives import (
+from sphinxcontrib.autodoc_pydantic.directives.directives import (
     PydanticField,
     PydanticConfigClass,
     PydanticValidator,
@@ -24,7 +26,9 @@ from sphinxcontrib.autodoc_pydantic.directives import (
     PydanticSettings
 )
 
-__version__ = "1.2.0"
+__version__ = "1.6.2"
+
+from sphinxcontrib.autodoc_pydantic.events import add_fallback_css_class
 
 
 def add_css_file(app: Sphinx, exception: Exception):
@@ -50,14 +54,14 @@ def add_domain_object_types(app: Sphinx):
 
     object_types = app.registry.domain_object_types.setdefault("py", {})
 
-    obj_types = ["pydantic_model",
-                 "pydantic_settings",
-                 "pydantic_field",
-                 "pydantic_validator",
-                 "pydantic_config"]
+    obj_types_mapping = {
+        ("field", "validator", "config"): ("obj", "any"),
+        ("model", "settings"): ("obj", "any", "class")
+    }
 
-    for obj_type in obj_types:
-        object_types[obj_type] = ObjType(obj_type, "obj", "any")
+    for obj_types, roles in obj_types_mapping.items():
+        for obj_type in obj_types:
+            object_types[f"pydantic_{obj_type}"] = ObjType(obj_type, *roles)
 
 
 def add_configuration_values(app: Sphinx):
@@ -67,16 +71,20 @@ def add_configuration_values(app: Sphinx):
 
     stem = "autodoc_pydantic_"
     add = app.add_config_value
+    json_strategy = OptionsJsonErrorStrategy.WARN
+    summary_list_order = OptionsSummaryListOrder.ALPHABETICAL
 
     add(f'{stem}config_signature_prefix', "model", True, str)
     add(f'{stem}config_members', True, True, bool)
 
     add(f'{stem}settings_show_json', True, True, bool)
+    add(f'{stem}settings_show_json_error_strategy', json_strategy, True, str)
     add(f'{stem}settings_show_config_member', False, True, bool)
     add(f'{stem}settings_show_config_summary', True, True, bool)
     add(f'{stem}settings_show_validator_members', True, True, bool)
     add(f'{stem}settings_show_validator_summary', True, True, bool)
     add(f'{stem}settings_show_field_summary', True, True, bool)
+    add(f'{stem}settings_summary_list_order', summary_list_order, True, str)
     add(f'{stem}settings_hide_paramlist', True, True, bool)
     add(f'{stem}settings_undoc_members', True, True, bool)
     add(f'{stem}settings_members', True, True, bool)
@@ -84,11 +92,13 @@ def add_configuration_values(app: Sphinx):
     add(f'{stem}settings_signature_prefix', "pydantic settings", True, str)
 
     add(f'{stem}model_show_json', True, True, bool)
+    add(f'{stem}model_show_json_error_strategy', json_strategy, True, str)
     add(f'{stem}model_show_config_member', False, True, bool)
     add(f'{stem}model_show_config_summary', True, True, bool)
     add(f'{stem}model_show_validator_members', True, True, bool)
     add(f'{stem}model_show_validator_summary', True, True, bool)
     add(f'{stem}model_show_field_summary', True, True, bool)
+    add(f'{stem}model_summary_list_order', summary_list_order, True, str)
     add(f'{stem}model_hide_paramlist', True, True, bool)
     add(f'{stem}model_undoc_members', True, True, bool)
     add(f'{stem}model_members', True, True, bool)
@@ -100,12 +110,15 @@ def add_configuration_values(app: Sphinx):
     add(f'{stem}validator_list_fields', False, True, bool)
 
     add(f'{stem}field_list_validators', True, True, bool)
-    add(f'{stem}field_doc_policy', 'both', True, str)
+    add(f'{stem}field_doc_policy', OptionsFieldDocPolicy.BOTH, True, str)
     add(f'{stem}field_show_constraints', True, True, bool)
     add(f'{stem}field_show_alias', True, True, bool)
     add(f'{stem}field_show_default', True, True, bool)
+    add(f'{stem}field_show_required', True, True, bool)
     add(f'{stem}field_signature_prefix', "field", True, str)
 
+    add(f'{stem}add_fallback_css_class', True, True, bool)
+
 
 def add_directives_and_autodocumenters(app: Sphinx):
     """Adds custom pydantic directives and autodocumenters to sphinx
@@ -119,13 +132,15 @@ def add_directives_and_autodocumenters(app: Sphinx):
     app.add_directive_to_domain("py", "pydantic_config", PydanticConfigClass)
     app.add_directive_to_domain("py", "pydantic_validator", PydanticValidator)
 
-    app.setup_extension('sphinx.ext.autodoc')  # Require autodoc extension
+    app.setup_extension('sphinx.ext.autodoc')
     app.add_autodocumenter(PydanticFieldDocumenter)
     app.add_autodocumenter(PydanticModelDocumenter)
     app.add_autodocumenter(PydanticSettingsDocumenter)
     app.add_autodocumenter(PydanticValidatorDocumenter)
     app.add_autodocumenter(PydanticConfigClassDocumenter)
 
+    app.connect('object-description-transform', add_fallback_css_class)
+
 
 def setup(app: Sphinx) -> Dict[str, Any]:
     add_configuration_values(app)
@@ -138,4 +153,4 @@ def setup(app: Sphinx) -> Dict[str, Any]:
         'version': __version__,
         'parallel_read_safe': True,
         'parallel_write_safe': True,
-    }
\ No newline at end of file
+    }
